// ============================================================================
// Rocks'n'Diamonds - McDuffin Strikes Back!
// ----------------------------------------------------------------------------
// (c) 1995-2014 by Artsoft Entertainment
//     		    Holger Schemel
//		    info@artsoft.org
//		    https://www.artsoft.org/
// ----------------------------------------------------------------------------
// game_sp.h
// ============================================================================

#ifndef GAME_SP_H
#define GAME_SP_H

#define GAME_SP_VERSION_1_0_0

#include "import_sp.h"
#include "export_sp.h"

#endif	// GAME_SP_H
